@@ -14,10 +14,18 @@ drawExtent <- function(show=TRUE, col="red") {
 	}
 	loc2 <- locator(n=1)
 	loc <- rbind(unlist(loc1), unlist(loc2))
-	bb <- extent(min(loc[,'x']), max(loc[,'x']), min(loc[,'y']), max(loc[,'y']))
+	e <- extent(min(loc[,'x']), max(loc[,'x']), min(loc[,'y']), max(loc[,'y']))
+	if (e@xmin == e@xmax) {
+		e@xmin <- e@xmin - 0.0000001
+		e@xmax <- e@xmax + 0.0000001
+	}
+	if (e@ymin == e@ymax) {
+		e@ymin <- e@ymin - 0.0000001
+		e@ymax <- e@ymax + 0.0000001
+	}
 	if (show) {
-		p <- rbind(c(bb@xmin, bb@ymin), c(bb@xmin, bb@ymax), c(bb@xmax, bb@ymax), c(bb@xmax, bb@ymin), c(bb@xmin, bb@ymin) )
+		p <- rbind(c(e@xmin, e@ymin), c(e@xmin, e@ymax), c(e@xmax, e@ymax), c(e@xmax, e@ymin), c(e@xmin, e@ymin) )
 		lines(p, col=col)
 	}
-	return(bb)
+	return(e)
 }
